==> Pyrogram-1.0.7-py3-none-any.whl: pyrogram/raw/base/channel_participants_filter.py <==
#  Pyrogram - Telegram MTProto API Client Library for Python
#  Copyright (C) 2017-2020 Dan <https://github.com/delivrance>
#
#  This file is part of Pyrogram.
#
#  Pyrogram is free software: you can redistribute it and/or modify
#  it under the terms of the GNU Lesser General Public License as published
#  by the Free Software Foundation, either version 3 of the License, or
#  (at your option) any later version.
#
#  Pyrogram is distributed in the hope that it will be useful,
#  but WITHOUT ANY WARRANTY; without even the implied warranty of
#  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
#  GNU Lesser General Public License for more details.
#
#  You should have received a copy of the GNU Lesser General Public License
#  along with Pyrogram.  If not, see <http://www.gnu.org/licenses/>.

# # # # # # # # # # # # # # # # # # # # # # # #
#               !!! WARNING !!!               #
#          This is a generated file!          #
# All changes made in this file will be lost! #
# # # # # # # # # # # # # # # # # # # # # # # #

from typing import Union
from pyrogram import raw
from pyrogram.raw.core import TLObject

ChannelParticipantsFilter = Union[raw.types.ChannelParticipantsAdmins, raw.types.ChannelParticipantsBanned, raw.types.ChannelParticipantsBots, raw.types.ChannelParticipantsContacts, raw.types.ChannelParticipantsKicked, raw.types.ChannelParticipantsRecent, raw.types.ChannelParticipantsSearch]


# noinspection PyRedeclaration
class ChannelParticipantsFilter:  # type: ignore
    """This base type has 7 constructors available.

    Constructors:
        .. hlist::
            :columns: 2

            - :obj:`ChannelParticipantsAdmins <pyrogram.raw.types.ChannelParticipantsAdmins>`
            - :obj:`ChannelParticipantsBanned <pyrogram.raw.types.ChannelParticipantsBanned>`
            - :obj:`ChannelParticipantsBots <pyrogram.raw.types.ChannelParticipantsBots>`
            - :obj:`ChannelParticipantsContacts <pyrogram.raw.types.ChannelParticipantsContacts>`
            - :obj:`ChannelParticipantsKicked <pyrogram.raw.types.ChannelParticipantsKicked>`
            - :obj:`ChannelParticipantsRecent <pyrogram.raw.types.ChannelParticipantsRecent>`
            - :obj:`ChannelParticipantsSearch <pyrogram.raw.types.ChannelParticipantsSearch>`
    """

    QUALNAME = "pyrogram.raw.base.ChannelParticipantsFilter"

    def __init__(self):
        raise TypeError("Base types can only be used for type checking purposes: "
                        "you tried to use a base type instance as argument, "
                        "but you need to instantiate one of its constructors instead. "
                        "More info: https://docs.pyrogram.org/telegram/base/channel-participants-filter")

==> Pyrogram-1.1.7-py3-none-any.whl: pyrogram/raw/base/channel_participants_filter.py <==
#  Pyrogram - Telegram MTProto API Client Library for Python
#  Copyright (C) 2017-2020 Dan <https://github.com/delivrance>
#
#  This file is part of Pyrogram.
#
#  Pyrogram is free software: you can redistribute it and/or modify
#  it under the terms of the GNU Lesser General Public License as published
#  by the Free Software Foundation, either version 3 of the License, or
#  (at your option) any later version.
#
#  Pyrogram is distributed in the hope that it will be useful,
#  but WITHOUT ANY WARRANTY; without even the implied warranty of
#  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
#  GNU Lesser General Public License for more details.
#
#  You should have received a copy of the GNU Lesser General Public License
#  along with Pyrogram.  If not, see <http://www.gnu.org/licenses/>.

# # # # # # # # # # # # # # # # # # # # # # # #
#               !!! WARNING !!!               #
#          This is a generated file!          #
# All changes made in this file will be lost! #
# # # # # # # # # # # # # # # # # # # # # # # #

from typing import Union
from pyrogram import raw
from pyrogram.raw.core import TLObject

ChannelParticipantsFilter = Union[raw.types.ChannelParticipantsAdmins, raw.types.ChannelParticipantsBanned, raw.types.ChannelParticipantsBots, raw.types.ChannelParticipantsContacts, raw.types.ChannelParticipantsKicked, raw.types.ChannelParticipantsMentions, raw.types.ChannelParticipantsRecent, raw.types.ChannelParticipantsSearch]


# noinspection PyRedeclaration
class ChannelParticipantsFilter:  # type: ignore
    """This base type has 8 constructors available.

    Constructors:
        .. hlist::
            :columns: 2

            - :obj:`ChannelParticipantsAdmins <pyrogram.raw.types.ChannelParticipantsAdmins>`
            - :obj:`ChannelParticipantsBanned <pyrogram.raw.types.ChannelParticipantsBanned>`
            - :obj:`ChannelParticipantsBots <pyrogram.raw.types.ChannelParticipantsBots>`
            - :obj:`ChannelParticipantsContacts <pyrogram.raw.types.ChannelParticipantsContacts>`
            - :obj:`ChannelParticipantsKicked <pyrogram.raw.types.ChannelParticipantsKicked>`
            - :obj:`ChannelParticipantsMentions <pyrogram.raw.types.ChannelParticipantsMentions>`
            - :obj:`ChannelParticipantsRecent <pyrogram.raw.types.ChannelParticipantsRecent>`
            - :obj:`ChannelParticipantsSearch <pyrogram.raw.types.ChannelParticipantsSearch>`
    """

    QUALNAME = "pyrogram.raw.base.ChannelParticipantsFilter"

    def __init__(self):
        raise TypeError("Base types can only be used for type checking purposes: "
                        "you tried to use a base type instance as argument, "
                        "but you need to instantiate one of its constructors instead. "
                        "More info: https://docs.pyrogram.org/telegram/base/channel-participants-filter")
